/* Copyright 2016 The TensorFlow Authors. All Rights Reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
==============================================================================*/

#ifndef TENSORFLOW_PLATFORM_WINDOWS_SUBPROCESS_H_
#define TENSORFLOW_PLATFORM_WINDOWS_SUBPROCESS_H_

#include <memory>
#include <vector>

#include "tensorflow/core/platform/logging.h"

namespace tensorflow {

// SubProcess is not yet implemented for Windows.
class SubProcess {};

std::unique_ptr<SubProcess> CreateSubProcess(const std::vector<string>& argv) {
  LOG(FATAL) << "CreateSubProcess NOT IMPLEMENTED for Windows yet ! ";
  return nullptr;
}

}  // namespace tensorflow

#endif  // TENSORFLOW_PLATFORM_WINDOWS_SUBPROCESS_H_
